package com.yanzhu.jh.project.mapper;

import java.util.List;
import com.yanzhu.jh.project.domain.BaseBuildNode;

/**
 * 项目建设节点Mapper接口
 * 
 * @author ruoyi
 * @date 2023-08-07
 */
public interface BaseBuildNodeMapper 
{
    /**
     * 查询项目建设节点
     * 
     * @param id 项目建设节点主键
     * @return 项目建设节点
     */
    public BaseBuildNode selectBaseBuildNodeById(Long id);

    /**
     * 查询项目建设节点列表
     * 
     * @param baseBuildNode 项目建设节点
     * @return 项目建设节点集合
     */
    public List<BaseBuildNode> selectBaseBuildNodeList(BaseBuildNode baseBuildNode);

    /**
     * 新增项目建设节点
     * 
     * @param baseBuildNode 项目建设节点
     * @return 结果
     */
    public int insertBaseBuildNode(BaseBuildNode baseBuildNode);

    /**
     * 修改项目建设节点
     * 
     * @param baseBuildNode 项目建设节点
     * @return 结果
     */
    public int updateBaseBuildNode(BaseBuildNode baseBuildNode);

    /**
     * 删除项目建设节点
     * 
     * @param id 项目建设节点主键
     * @return 结果
     */
    public int deleteBaseBuildNodeById(Long id);

    /**
     * 批量删除项目建设节点
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBaseBuildNodeByIds(Long[] ids);

    public List<BaseBuildNode> selectByProject(long projectId);
}
