package com.yanzhu.jh.project.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.project.domain.BaseBuildNode;
import com.yanzhu.jh.project.service.IBaseBuildNodeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 项目建设节点Controller
 * 
 * @author ruoyi
 * @date 2023-08-07
 */
@RestController
@RequestMapping("/project/build_node")
public class BaseBuildNodeController extends BaseController
{
    @Autowired
    private IBaseBuildNodeService baseBuildNodeService;

    /**
     * 查询项目建设节点列表
     */
    @PreAuthorize("@ss.hasPermi('project:build_node:list')")
    @GetMapping("/list")
    public TableDataInfo list(BaseBuildNode baseBuildNode)
    {
        startPage();
        List<BaseBuildNode> list = baseBuildNodeService.selectBaseBuildNodeList(baseBuildNode);
        return getDataTable(list);
    }

    /**
     * 导出项目建设节点列表
     */
    @PreAuthorize("@ss.hasPermi('project:build_node:export')")
    @Log(title = "项目建设节点", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseBuildNode baseBuildNode)
    {
        List<BaseBuildNode> list = baseBuildNodeService.selectBaseBuildNodeList(baseBuildNode);
        ExcelUtil<BaseBuildNode> util = new ExcelUtil<BaseBuildNode>(BaseBuildNode.class);
        util.exportExcel(response, list, "项目建设节点数据");
    }

    /**
     * 获取项目建设节点详细信息
     */
    @PreAuthorize("@ss.hasPermi('project:build_node:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(baseBuildNodeService.selectBaseBuildNodeById(id));
    }

    /**
     * 新增项目建设节点
     */
    @PreAuthorize("@ss.hasPermi('project:build_node:add')")
    @Log(title = "项目建设节点", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseBuildNode baseBuildNode)
    {
        return toAjax(baseBuildNodeService.insertBaseBuildNode(baseBuildNode));
    }

    /**
     * 修改项目建设节点
     */
    @PreAuthorize("@ss.hasPermi('project:build_node:edit')")
    @Log(title = "项目建设节点", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseBuildNode baseBuildNode)
    {
        return toAjax(baseBuildNodeService.updateBaseBuildNode(baseBuildNode));
    }

    /**
     * 删除项目建设节点
     */
    @PreAuthorize("@ss.hasPermi('project:build_node:remove')")
    @Log(title = "项目建设节点", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(baseBuildNodeService.deleteBaseBuildNodeByIds(ids));
    }


}
